==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/fragments/MyChatFragment.java <==
package com.hippoagent.fragments;//package com.fuguagent.fragments;
//
//import android.content.Intent;
//import android.os.Bundle;
//import androidx.annotation.Nullable;
//import androidx.fragment.app.Fragment;
//import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;
//import androidx.recyclerview.widget.DefaultItemAnimator;
//import androidx.recyclerview.widget.LinearLayoutManager;
//import androidx.recyclerview.widget.RecyclerView;
//import android.view.LayoutInflater;
//import android.view.View;
//import android.view.ViewGroup;
//import android.widget.LinearLayout;
//
//import com.fuguagent.MyApplication;
//import com.fuguagent.R;
//import com.fuguagent.activities.FuguChatActivity;
//import com.fuguagent.activities.MainActivity;
//import com.fuguagent.adapters.MyChatAdapter;
//import com.fuguagent.model.Conversation;
//import com.fuguagent.com.hippoagentsdk.utils.Constants;
//import com.fuguagent.com.hippoagentsdk.utils.Log;
//import com.google.gson.Gson;
//
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * Created by ankit on 29/05/17.
// */
//
//public class MyChatFragment extends Fragment implements SwipeRefreshLayout.OnRefreshListener {
//
//    private View root;
//    private SwipeRefreshLayout srLayout;
//    private RecyclerView rvMychat;
//    private MyChatAdapter myChatAdapter;
//    private ArrayList<Object> myChatList = new ArrayList<>();
//    LinearLayoutManager layoutManager;
//    private int pastVisiblesItems, visibleItemCount, totalItemCount;
//    private LinearLayout llNoConversation;
//
//    public MyChatFragment() {
//    }
//
//    @Nullable
//    @Override
//    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
//        root = inflater.inflate(R.layout.mychat_fragment, container, false);
//        return root;
//    }
//
//    @Override
//    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
//        super.onViewCreated(view, savedInstanceState);
//
//        srLayout = (SwipeRefreshLayout) root.findViewById(R.id.srLayout);
//        srLayout.setOnRefreshListener(this);
//        srLayout.setColorSchemeResources(R.color.white);
//        srLayout.setProgressBackgroundColorSchemeResource(R.color.colorPrimary);
//        srLayout.setSize(SwipeRefreshLayout.DEFAULT);
//        llNoConversation = (LinearLayout) root.findViewById(R.id.llNoConversation);
//        rvMychat = (RecyclerView) root.findViewById(R.id.rvAssigned);
//        layoutManager = new LinearLayoutManager(getActivity());
//        rvMychat.setLayoutManager(layoutManager);
//        rvMychat.setItemAnimator(new DefaultItemAnimator());
//        rvMychat.setHasFixedSize(false);
//
//        myChatAdapter = new MyChatAdapter(myChatList, getActivity(), new MyChatAdapter.Callback() {
//            @Override
//            public void onClick(int position, Conversation conversation) {
//                conversation.setUnreadCount(0);
//                myChatAdapter.notifyDataSetChanged();
//                setAllChatConversationCount(conversation);
//                Intent chatIntent = new Intent(getActivity(), FuguChatActivity.class);
//                chatIntent.putExtra(Constants.CONVERSATION, new Gson().toJson(conversation, Conversation.class));
//                startActivityForResult(chatIntent, 100);
//            }
//        });
//        rvMychat.setAdapter(myChatAdapter);
//
//        if (((MainActivity) getActivity()).getHomeFragment().isGetConversationApiHit() && myChatList.size() == 0) {
//            llNoConversation.setVisibility(View.VISIBLE);
//        } else {
//            llNoConversation.setVisibility(View.GONE);
//        }
//
//        rvMychat.addOnScrollListener(new RecyclerView.OnScrollListener() {
//            @Override
//            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
//                super.onScrollStateChanged(recyclerView, newState);
//            }
//
//            @Override
//            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
//                //To implement Pagination
//                if (dy > 0) {
//                    visibleItemCount = layoutManager.getChildCount();
//                    totalItemCount = layoutManager.getItemCount();
//                    pastVisiblesItems = layoutManager.findFirstVisibleItemPosition();
//
//                    if (!((MainActivity) getActivity()).getHomeFragment().isPagingApiInProgress()) {
//                        if ((visibleItemCount + pastVisiblesItems) >= totalItemCount) {
//                            fetchNextPage();
//                        }
//                    }
//                }
//            }
//        });
//    }
//
//    private void setAllChatConversationCount(Conversation conversationCount) {
//        /*for (Conversation conversation : ((MainActivity) getActivity()).getHomeFragment().getAllChatList()) {
//            if (conversation.getChannelId().equals(conversationCount.getChannelId())) {
//                conversation.setUnreadCount(0);
//                break;
//            }
//        }*/
//    }
//
//    public SwipeRefreshLayout getSrLayout() {
//        return srLayout;
//    }
//
//    private void fetchNextPage() {
//        if(((MainActivity) getActivity()).isNetworkAvailable()) {
//            ((MainActivity) getActivity()).getHomeFragment().setPagingApiInProgress(true);
//            toggleProgressBarVisibility(true);
//            int pageStart = myChatList.size();
//            if (myChatList.contains(progressBarItem)) {
//                pageStart = myChatList.size();
//            }
//            ((MainActivity) getActivity()).getHomeFragment().apiGetConversation(String.valueOf(MyApplication.getInstance().getUserData().getUserId()), ((MainActivity) getActivity()).getStatusIntArray()
//                    , ((MainActivity) getActivity()).getTypeIntArray(), ((MainActivity) getActivity()).getLabelsIntArray(), pageStart, true, true, true);
//        }
//    }
//
//    @Override
//    public void onActivityResult(int requestCode, int resultCode, Intent data) {
//        super.onActivityResult(requestCode, resultCode, data);
//        Log.v("onActivityResult", "enter");
//        if (requestCode == 100) {
//
//        }
//    }
//
//    private MyChatAdapter.ProgressBarItem progressBarItem;
//
//    public void toggleProgressBarVisibility(boolean isVisible) {
//        if (isVisible) {
//            if (progressBarItem == null) {
//                progressBarItem = new MyChatAdapter.ProgressBarItem();
//            }
//            if (!myChatList.contains(progressBarItem)) {
//                myChatList.add(progressBarItem);
//                myChatAdapter.notifyItemInserted(myChatList.size() - 1);
//            }
//        } else {
//            if (progressBarItem != null && myChatList.contains(progressBarItem)) {
//                myChatList.remove(progressBarItem);
//                myChatAdapter.notifyItemRemoved(myChatList.size() - 1);
//            }
//        }
//    }
//
//    private ArrayList<Object> getAdapterList(List<Conversation> myChatDetailList) {
//        if (myChatList == null) {
//            myChatList = new ArrayList<>();
//        }
//        myChatList.clear();
//
//        if (myChatDetailList != null && myChatDetailList.size() > 0) {
//            myChatList.addAll(myChatDetailList);
//        }
//        return myChatList;
//    }
//
//    public void setMyChatData(ArrayList<Conversation> myChatData, boolean isPagination) {
//        if (!isPagination) {
//            myChatList.clear();
//        }
//        myChatList.addAll(myChatData);
//        if (getView() != null && myChatAdapter != null) {
//            getActivity().runOnUiThread(new Runnable() {
//                @Override
//                public void run() {
//                    myChatAdapter.notifyDataSetChanged();
//                }
//            });
//
//        }
//
//        if (llNoConversation != null) {
//            if (myChatList.size() == 0) {
//                llNoConversation.setVisibility(View.VISIBLE);
//            } else {
//                llNoConversation.setVisibility(View.GONE);
//            }
//        }
//    }
//
//    @Override
//    public void onRefresh() {
//        if(((MainActivity) getActivity()).isNetworkAvailable()) {
//            ((MainActivity) getActivity()).getHomeFragment().apiGetConversation(String.valueOf(MyApplication.getInstance().getUserData().getUserId()),((MainActivity) getActivity()).getStatusIntArray()
//                    , ((MainActivity) getActivity()).getTypeIntArray(), ((MainActivity) getActivity()).getLabelsIntArray(), 1, false, false, true);
//        } else {
//            getSrLayout().setRefreshing(false);
//        }
//    }
//}

==> hippoagentsdk-0.1.3-sources.jar: com/hippoagent/fragments/MyChatFragment.java <==
package com.hippoagent.fragments;//package com.fuguagent.fragments;
//
//import android.content.Intent;
//import android.os.Bundle;
//import androidx.annotation.Nullable;
//import androidx.fragment.app.Fragment;
//import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;
//import androidx.recyclerview.widget.DefaultItemAnimator;
//import androidx.recyclerview.widget.LinearLayoutManager;
//import androidx.recyclerview.widget.RecyclerView;
//import android.view.LayoutInflater;
//import android.view.View;
//import android.view.ViewGroup;
//import android.widget.LinearLayout;
//
//import com.fuguagent.HippoApplication;
//import com.fuguagent.R;
//import com.fuguagent.activities.FuguChatActivity;
//import com.fuguagent.activities.MainActivity;
//import com.fuguagent.adapters.MyChatAdapter;
//import com.fuguagent.model.Conversation;
//import com.fuguagent.com.hippoagentsdk.utils.Constants;
//import com.fuguagent.com.hippoagentsdk.utils.Log;
//import com.google.gson.Gson;
//
//import java.util.ArrayList;
//import java.util.List;
//
///**
// * Created by ankit on 29/05/17.
// */
//
//public class MyChatFragment extends Fragment implements SwipeRefreshLayout.OnRefreshListener {
//
//    private View root;
//    private SwipeRefreshLayout srLayout;
//    private RecyclerView rvMychat;
//    private MyChatAdapter myChatAdapter;
//    private ArrayList<Object> myChatList = new ArrayList<>();
//    LinearLayoutManager layoutManager;
//    private int pastVisiblesItems, visibleItemCount, totalItemCount;
//    private LinearLayout llNoConversation;
//
//    public MyChatFragment() {
//    }
//
//    @Nullable
//    @Override
//    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
//        root = inflater.inflate(R.layout.mychat_fragment, container, false);
//        return root;
//    }
//
//    @Override
//    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
//        super.onViewCreated(view, savedInstanceState);
//
//        srLayout = (SwipeRefreshLayout) root.findViewById(R.id.srLayout);
//        srLayout.setOnRefreshListener(this);
//        srLayout.setColorSchemeResources(R.color.white);
//        srLayout.setProgressBackgroundColorSchemeResource(R.color.colorPrimary);
//        srLayout.setSize(SwipeRefreshLayout.DEFAULT);
//        llNoConversation = (LinearLayout) root.findViewById(R.id.llNoConversation);
//        rvMychat = (RecyclerView) root.findViewById(R.id.rvAssigned);
//        layoutManager = new LinearLayoutManager(getActivity());
//        rvMychat.setLayoutManager(layoutManager);
//        rvMychat.setItemAnimator(new DefaultItemAnimator());
//        rvMychat.setHasFixedSize(false);
//
//        myChatAdapter = new MyChatAdapter(myChatList, getActivity(), new MyChatAdapter.Callback() {
//            @Override
//            public void onClick(int position, Conversation conversation) {
//                conversation.setUnreadCount(0);
//                myChatAdapter.notifyDataSetChanged();
//                setAllChatConversationCount(conversation);
//                Intent chatIntent = new Intent(getActivity(), FuguChatActivity.class);
//                chatIntent.putExtra(Constants.CONVERSATION, new Gson().toJson(conversation, Conversation.class));
//                startActivityForResult(chatIntent, 100);
//            }
//        });
//        rvMychat.setAdapter(myChatAdapter);
//
//        if (((MainActivity) getActivity()).getHomeFragment().isGetConversationApiHit() && myChatList.size() == 0) {
//            llNoConversation.setVisibility(View.VISIBLE);
//        } else {
//            llNoConversation.setVisibility(View.GONE);
//        }
//
//        rvMychat.addOnScrollListener(new RecyclerView.OnScrollListener() {
//            @Override
//            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
//                super.onScrollStateChanged(recyclerView, newState);
//            }
//
//            @Override
//            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
//                //To implement Pagination
//                if (dy > 0) {
//                    visibleItemCount = layoutManager.getChildCount();
//                    totalItemCount = layoutManager.getItemCount();
//                    pastVisiblesItems = layoutManager.findFirstVisibleItemPosition();
//
//                    if (!((MainActivity) getActivity()).getHomeFragment().isPagingApiInProgress()) {
//                        if ((visibleItemCount + pastVisiblesItems) >= totalItemCount) {
//                            fetchNextPage();
//                        }
//                    }
//                }
//            }
//        });
//    }
//
//    private void setAllChatConversationCount(Conversation conversationCount) {
//        /*for (Conversation conversation : ((MainActivity) getActivity()).getHomeFragment().getAllChatList()) {
//            if (conversation.getChannelId().equals(conversationCount.getChannelId())) {
//                conversation.setUnreadCount(0);
//                break;
//            }
//        }*/
//    }
//
//    public SwipeRefreshLayout getSrLayout() {
//        return srLayout;
//    }
//
//    private void fetchNextPage() {
//        if(((MainActivity) getActivity()).isNetworkAvailable()) {
//            ((MainActivity) getActivity()).getHomeFragment().setPagingApiInProgress(true);
//            toggleProgressBarVisibility(true);
//            int pageStart = myChatList.size();
//            if (myChatList.contains(progressBarItem)) {
//                pageStart = myChatList.size();
//            }
//            ((MainActivity) getActivity()).getHomeFragment().apiGetConversation(String.valueOf(HippoApplication.getInstance().getUserData().getUserId()), ((MainActivity) getActivity()).getStatusIntArray()
//                    , ((MainActivity) getActivity()).getTypeIntArray(), ((MainActivity) getActivity()).getLabelsIntArray(), pageStart, true, true, true);
//        }
//    }
//
//    @Override
//    public void onActivityResult(int requestCode, int resultCode, Intent data) {
//        super.onActivityResult(requestCode, resultCode, data);
//        Log.v("onActivityResult", "enter");
//        if (requestCode == 100) {
//
//        }
//    }
//
//    private MyChatAdapter.ProgressBarItem progressBarItem;
//
//    public void toggleProgressBarVisibility(boolean isVisible) {
//        if (isVisible) {
//            if (progressBarItem == null) {
//                progressBarItem = new MyChatAdapter.ProgressBarItem();
//            }
//            if (!myChatList.contains(progressBarItem)) {
//                myChatList.add(progressBarItem);
//                myChatAdapter.notifyItemInserted(myChatList.size() - 1);
//            }
//        } else {
//            if (progressBarItem != null && myChatList.contains(progressBarItem)) {
//                myChatList.remove(progressBarItem);
//                myChatAdapter.notifyItemRemoved(myChatList.size() - 1);
//            }
//        }
//    }
//
//    private ArrayList<Object> getAdapterList(List<Conversation> myChatDetailList) {
//        if (myChatList == null) {
//            myChatList = new ArrayList<>();
//        }
//        myChatList.clear();
//
//        if (myChatDetailList != null && myChatDetailList.size() > 0) {
//            myChatList.addAll(myChatDetailList);
//        }
//        return myChatList;
//    }
//
//    public void setMyChatData(ArrayList<Conversation> myChatData, boolean isPagination) {
//        if (!isPagination) {
//            myChatList.clear();
//        }
//        myChatList.addAll(myChatData);
//        if (getView() != null && myChatAdapter != null) {
//            getActivity().runOnUiThread(new Runnable() {
//                @Override
//                public void run() {
//                    myChatAdapter.notifyDataSetChanged();
//                }
//            });
//
//        }
//
//        if (llNoConversation != null) {
//            if (myChatList.size() == 0) {
//                llNoConversation.setVisibility(View.VISIBLE);
//            } else {
//                llNoConversation.setVisibility(View.GONE);
//            }
//        }
//    }
//
//    @Override
//    public void onRefresh() {
//        if(((MainActivity) getActivity()).isNetworkAvailable()) {
//            ((MainActivity) getActivity()).getHomeFragment().apiGetConversation(String.valueOf(HippoApplication.getInstance().getUserData().getUserId()),((MainActivity) getActivity()).getStatusIntArray()
//                    , ((MainActivity) getActivity()).getTypeIntArray(), ((MainActivity) getActivity()).getLabelsIntArray(), 1, false, false, true);
//        } else {
//            getSrLayout().setRefreshing(false);
//        }
//    }
//}
